@@ -7,6 +7,11 @@ V1_FARES_URL = V1 + "/fares/dataset"
 V1_GTFS_RT_URL = V1 + "/gtfsrtdatafeed"
 V1_SIRI_VM_URL = V1 + "/datafeed"
 
+TIMETABLES_PATH = "dataset"
+FARES_PATH = "fares/dataset"
+GTFS_RT_PATH = "gtfsrtdatafeed"
+SIRI_VM_PATH = "datafeed"
+
 DATASET_STATUSES = ["published", "error", "expired", "inactive"]
 
 OK_200 = 200
