@@ -20,6 +20,9 @@ class Timetable(BaseDataset):
     first_start_date: datetime = Field(alias="firstStartDate")
     first_end_date: datetime = Field(None, alias="firstEndDate")
     last_end_date: datetime = Field(None, alias="lastEndDate")
+    dq_score: str = Field(alias="dqScore")
+    dq_rag: str = Field(alias="dqRag")
+    bods_compliance: bool = Field(None, alias="bodsCompliance")
 
 
 class TimetableParams(BaseAPIParams):
@@ -33,6 +36,8 @@ class TimetableParams(BaseAPIParams):
     start_date_end: Optional[datetime] = Field(None, alias="startDateStart")
     end_date_start: Optional[datetime] = Field(None, alias="endDateStart")
     end_date_end: Optional[datetime] = Field(None, alias="endDateEnd")
+    dq_rag: Optional[str] = Field(None, alias="dqRag")
+    bods_compliance: Optional[bool] = Field(None, alias="bodsCompliance")
 
 
 class TimetableResponse(BaseAPIResponse):
